# coding: utf-8

"""
    Embeddings API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.content_evaluation_response_quality_score_breakdown_readability import ContentEvaluationResponseQualityScoreBreakdownReadability

class TestContentEvaluationResponseQualityScoreBreakdownReadability(unittest.TestCase):
    """ContentEvaluationResponseQualityScoreBreakdownReadability unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ContentEvaluationResponseQualityScoreBreakdownReadability:
        """Test ContentEvaluationResponseQualityScoreBreakdownReadability
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ContentEvaluationResponseQualityScoreBreakdownReadability`
        """
        model = ContentEvaluationResponseQualityScoreBreakdownReadability()
        if include_optional:
            return ContentEvaluationResponseQualityScoreBreakdownReadability(
                score = 1.337,
                grade_level = 56,
                complex_sentences = wordlift_client.models.content_evaluation_response_quality_score_breakdown_readability_complex_sentences.ContentEvaluationResponse_quality_score_breakdown_readability_complex_sentences(
                    hard = 56, 
                    very_hard = 56, 
                    total = 56, )
            )
        else:
            return ContentEvaluationResponseQualityScoreBreakdownReadability(
                score = 1.337,
                grade_level = 56,
                complex_sentences = wordlift_client.models.content_evaluation_response_quality_score_breakdown_readability_complex_sentences.ContentEvaluationResponse_quality_score_breakdown_readability_complex_sentences(
                    hard = 56, 
                    very_hard = 56, 
                    total = 56, ),
        )
        """

    def testContentEvaluationResponseQualityScoreBreakdownReadability(self):
        """Test ContentEvaluationResponseQualityScoreBreakdownReadability"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
