# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.rules_api import RulesApi


class TestRulesApi(unittest.TestCase):
    """RulesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RulesApi()

    def tearDown(self) -> None:
        pass

    def test_copy_rules(self) -> None:
        """Test case for copy_rules

        Copy
        """
        pass

    def test_create_rule(self) -> None:
        """Test case for create_rule

        Create
        """
        pass

    def test_delete_rule(self) -> None:
        """Test case for delete_rule

        Delete
        """
        pass

    def test_list_rules(self) -> None:
        """Test case for list_rules

        List
        """
        pass

    def test_update_rule(self) -> None:
        """Test case for update_rule

        Update
        """
        pass

    def test_update_rule_collection(self) -> None:
        """Test case for update_rule_collection

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()
